@@ -137,6 +137,20 @@ class Order(object):
             files.append(file_hash.get(f, None))
         files = [ i for i in files if i is not None ]
 
+class DirectoryIndicator(FormatterBase):
+    """indicate a directory"""
+    indicator = '/'
+    def __init__(self, indicator):
+        self.indicator = indicator.strip() or self.indicator
+    def __call__(self, request, data):
+        for f in data['files']:
+            if f.get('type') == 'directory':
+                title = f.get('title')
+                if title is not None:
+                    f['title'] = '%s %s' % (title, self.indicator)
+                else:
+                    description = f.get('description') or f['name']
+                    f['description'] = '%s %s' % (description, self.indicator)
 
 class FilenameDescription(FormatterBase):
     """
@@ -144,6 +158,7 @@ class FilenameDescription(FormatterBase):
     the file extension (if any) will be dropped and
     spaces will be substituted for underscores
     """
+
     # TODO : deal with CamelCaseFilenames
 
     separators = ['_', '-'] # space substitute separators
@@ -238,7 +253,6 @@ class Links(FormatterBase):
     fatal = False
     defaults = {'separator': ';'}
 
-
     def __call__(self, request, data):
         for f in data['files']:
             if f['description'] and self.separator in f['description']:
@@ -314,7 +328,8 @@ class Include(object):
     def __call__(self, request, data):
         data['include'] = self.include
 
-###
+
+### general purpose functions for formatters
 
 def formatters():
     formatters = {}
